.. Lexilux documentation master file

Lexilux Documentation
========================

Welcome to Lexilux's documentation!

Lexilux is a unified LLM API client library that makes calling Chat, Embedding, Rerank, and Tokenizer APIs as simple as calling a function.

.. grid:: 2
   :gutter: 2
   :margin: 2

   .. grid-item-card::
      :link: introduction
      :link-type: doc
      
      **Getting Started**
      
      Learn the basics and key concepts of Lexilux.

   .. grid-item-card::
      :link: quickstart
      :link-type: doc
      
      **Quick Start**
      
      Get up and running with Lexilux in minutes.

   .. grid-item-card::
      :link: api_reference/index
      :link-type: doc
      
      **API Reference**
      
      Complete API documentation for all classes and methods.

   .. grid-item-card::
      :link: examples/index
      :link-type: doc
      
      **Examples**
      
      Real-world code examples and use cases.

.. toctree::
   :maxdepth: 2
   :caption: Documentation
   :hidden:

   introduction
   installation
   quickstart
   recommended_workflows
   error_handling
   chat_history
   chat_formatting
   chat_streaming
   chat_continue
   token_analysis
   api_reference/index
   examples/index
   rerank_modes_comparison
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

